xsdata.codegen.handlers.class\_extension module
===============================================

.. automodule:: xsdata.codegen.handlers.class_extension
   :members:
   :undoc-members:
   :show-inheritance:
